@@ -25,26 +25,26 @@ from .seat_map import SeatMap
 from .webhook import Webhook
 
 __all__ = [
-    Aircraft,
-    Airline,
-    Airport,
-    City,
-    LoyaltyProgrammeAccount,
-    Passenger,
-    Place,
-    Offer,
-    OfferConditionChangeBeforeDeparture,
-    OfferConditionRefundBeforeDeparture,
-    OfferRequest,
-    Order,
-    OrderConditionChangeBeforeDeparture,
-    OrderConditionRefundBeforeDeparture,
-    OrderCancellation,
-    OrderChange,
-    OrderChangeOffer,
-    OrderChangeRequest,
-    Payment,
-    PaymentIntent,
-    SeatMap,
-    Webhook,
+    "Aircraft",
+    "Airline",
+    "Airport",
+    "City",
+    "LoyaltyProgrammeAccount",
+    "Passenger",
+    "Place",
+    "Offer",
+    "OfferConditionChangeBeforeDeparture",
+    "OfferConditionRefundBeforeDeparture",
+    "OfferRequest",
+    "Order",
+    "OrderConditionChangeBeforeDeparture",
+    "OrderConditionRefundBeforeDeparture",
+    "OrderCancellation",
+    "OrderChange",
+    "OrderChangeOffer",
+    "OrderChangeRequest",
+    "Payment",
+    "PaymentIntent",
+    "SeatMap",
+    "Webhook",
 ]
