@@ -1,9 +1,9 @@
 from ..models import (
-    Airline,
-    Place,
     Aircraft,
+    Airline,
     OfferConditionChangeBeforeDeparture,
     OfferConditionRefundBeforeDeparture,
+    Place,
 )
 from ..utils import maybe_parse_date_entries
 
@@ -19,25 +19,40 @@ class Order:
 
     def __init__(self, json):
         for key in json:
-            value = json[key]
-            if value is not None:
-                value = maybe_parse_date_entries(key, json[key])
-            if key == "documents":
-                value = [OrderDocument(v) for v in value]
-            elif key == "conditions":
-                value = OrderConditions(value)
-            elif key == "owner":
-                value = Airline(value)
-            elif key == "passengers":
-                value = [OrderPassenger(v) for v in value]
-            elif key == "payment_status":
-                value = OrderPaymentStatus(value)
-            elif key == "services":
-                value = [OrderService(v) for v in value]
-            elif key == "slices":
-                value = [OrderSlice(v) for v in value]
+            value = Order.__maybe_init_value(key, json)
+
             setattr(self, key, value)
 
+    @staticmethod
+    def __maybe_init_value(key, json):
+        value = json[key]
+
+        if isinstance(value, str):
+            value = maybe_parse_date_entries(key, json[key])
+        elif isinstance(value, dict):
+            # Metadata is customer-specified data, so we don't try and parse it
+            if key == "metadata":
+                return value
+
+            parsers = {
+                "conditions": OrderConditions,
+                "owner": Airline,
+                "payment_status": OrderPaymentStatus,
+            }
+
+            value = parsers[key](value)
+        elif isinstance(value, list):
+            parsers = {
+                "documents": OrderDocument,
+                "passengers": OrderPassenger,
+                "services": OrderService,
+                "slices": OrderSlice,
+            }
+
+            value = [parsers[key](v) for v in value]
+
+        return value
+
 
 class OrderConditions:
     """The conditions associated with this order, describing the kinds of modifications you
@@ -53,10 +68,13 @@ class OrderConditions:
 
     def __init__(self, json):
         for key in json:
+            value = json[key]
+
             if key == "change_before_departure":
                 value = OrderConditionChangeBeforeDeparture(json[key])
             elif key == "refund_before_departure":
                 value = OrderConditionRefundBeforeDeparture(json[key])
+
             setattr(self, key, value)
 
 
@@ -77,14 +95,23 @@ class OrderSlice:
 
     def __init__(self, json):
         for key in json:
-            value = maybe_parse_date_entries(key, json[key])
+            value = json[key]
+
+            if isinstance(value, str):
+                value = maybe_parse_date_entries(key, json[key])
+                setattr(self, key, value)
+                continue
+
             if key in ["destination", "origin"]:
                 value = Place(value)
             elif key in ["destination_type", "origin_type"]:
                 if value not in OrderSlice.allowed_place_types:
                     raise OrderSlice.InvalidPlaceType(value)
-            elif key == "segments":
-                value = [OrderSliceSegment(v) for v in value]
+
+            if isinstance(value, list):
+                if key == "segments":
+                    value = [OrderSliceSegment(v) for v in value]
+
             # TODO(nlopes): maybe convert duration to a timedelta or Duration
             setattr(self, key, value)
 
@@ -97,7 +124,13 @@ class OrderSliceSegment:
 
     def __init__(self, json):
         for key in json:
-            value = maybe_parse_date_entries(key, json[key])
+            value = json[key]
+
+            if isinstance(value, str):
+                value = maybe_parse_date_entries(key, json[key])
+                setattr(self, key, value)
+                continue
+
             if key == "aircraft" and value:
                 value = Aircraft(value)
             elif key in ["marketing_carrier", "operating_carrier"] and value:
@@ -106,6 +139,7 @@ class OrderSliceSegment:
                 value = Place(value)
             elif key == "passengers":
                 value = [OrderSliceSegmentPassenger(p) for p in value]
+
             setattr(self, key, value)
 
 
@@ -122,9 +156,12 @@ class OrderSliceSegmentPassenger:
     def __init__(self, json):
         for key in json:
             value = json[key]
-            if key == "baggages":
-                value = [OrderSliceSegmentPassengerBaggage(v) for v in value]
-            elif key == "seat":
+
+            if isinstance(value, list):
+                if key == "baggages":
+                    value = [OrderSliceSegmentPassengerBaggage(v) for v in value]
+
+            if key == "seat":
                 if value is not None:
                     value = OrderSliceSegmentPassengerSeat(value)
             elif key == "cabin_class":
@@ -223,8 +260,12 @@ class OrderPaymentStatus:
     def __init__(self, json):
         for key in json:
             value = json[key]
-            if value is not None:
+
+            if isinstance(value, str):
                 value = maybe_parse_date_entries(key, json[key])
+                setattr(self, key, value)
+                continue
+
             setattr(self, key, value)
 
 
@@ -246,13 +287,20 @@ class OrderPassenger:
 
     def __init__(self, json):
         for key in json:
-            value = maybe_parse_date_entries(key, json[key])
+            value = json[key]
+
+            if isinstance(value, str):
+                value = maybe_parse_date_entries(key, json[key])
+                setattr(self, key, value)
+                continue
+
             if key == "gender" and value.lower() not in OrderPassenger.allowed_genders:
                 raise OrderPassenger.InvalidGender(value)
             elif key == "title" and value.lower() not in OrderPassenger.allowed_titles:
                 raise OrderPassenger.InvalidTitle(value)
             elif key == "type" and value.lower() not in OrderPassenger.allowed_types:
                 raise OrderPassenger.InvalidType(value)
+
             setattr(self, key, value)
 
 
